@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Stephan Zednik <zednik@ucar.edu> and Patrick West <pwest@ucar.edu>
 // and Jose Garcia <jgarcia@ucar.edu>
 //
@@ -54,56 +54,57 @@ using std::endl ;
 void
 CSVModule::initialize( const string &modname )
 {
-    BESDEBUG( "csv", "Initializing CSV Module " << modname << endl )
+    BESDEBUG( "csv", "Initializing CSV Module " << modname << endl ) ;
 
-    BESDEBUG( "csv", "    adding " << modname << " request handler" << endl )
+    BESDEBUG( "csv", "    adding " << modname << " request handler" << endl ) ;
     BESRequestHandlerList::TheList()->
 	add_handler( modname, new CSVRequestHandler( modname ) ) ;
 
-    BESDEBUG( "csv", "    adding " << CSV_CATALOG << " catalog" << endl )
-    if( !BESCatalogList::TheCatalogList()->find_catalog( CSV_CATALOG ) )
+    BESDEBUG( "csv", "    adding " << CSV_CATALOG << " catalog" << endl ) ;
+    if( !BESCatalogList::TheCatalogList()->ref_catalog( CSV_CATALOG ) )
     {
 	BESCatalogList::TheCatalogList()->
 	    add_catalog(new BESCatalogDirectory( CSV_CATALOG ) ) ;
     }
     else
     {
-	BESDEBUG( "csv", "    catalog already exists, skipping" << endl )
+	BESDEBUG( "csv", "    catalog already exists, skipping" << endl ) ;
     }
 
-    BESDEBUG( "csv", "    adding Catalog Container Storage" << endl )
-    if( !BESContainerStorageList::TheList()->find_persistence( CSV_CATALOG ) )
+    BESDEBUG( "csv", "    adding Catalog Container Storage" << endl ) ;
+    if( !BESContainerStorageList::TheList()->ref_persistence( CSV_CATALOG ) )
     {
 	BESContainerStorageList::TheList()->
 	    add_persistence( new BESContainerStorageCatalog( CSV_CATALOG ) ) ;
     }
     else
     {
-	BESDEBUG( "csv", "    storage already exists, skipping" << endl )
+	BESDEBUG( "csv", "    storage already exists, skipping" << endl ) ;
     }
 
-    BESDEBUG( "csv", "    adding csv debug context" << endl )
+    BESDEBUG( "csv", "    adding csv debug context" << endl ) ;
     BESDebug::Register( "csv" ) ;
 
-    BESDEBUG( "csv", "Done Initializing CSV Handler " << modname << endl )
+    BESDEBUG( "csv", "Done Initializing CSV Handler " << modname << endl ) ;
 }
 
 void
 CSVModule::terminate( const string &modname )
 {
-    BESDEBUG( "csv", "Cleaning CSV Module" << modname << endl )
+    BESDEBUG( "csv", "Cleaning CSV Module" << modname << endl ) ;
 
-    BESDEBUG( "csv", "    removing " << modname << " request handler" << endl )
+    BESDEBUG( "csv", "    removing " << modname << " request handler" << endl );
     BESRequestHandler *rh = BESRequestHandlerList::TheList()->remove_handler( modname ) ;
     if( rh ) delete rh ;
     
-    BESDEBUG( "csv", "    removing catalog container storage" << CSV_CATALOG << endl )
-    BESContainerStorageList::TheList()->del_persistence( CSV_CATALOG ) ;
+    BESDEBUG( "csv", "    removing catalog container storage"
+		     << CSV_CATALOG << endl ) ;
+    BESContainerStorageList::TheList()->deref_persistence( CSV_CATALOG ) ;
 
-    BESDEBUG( "csv", "    removing " << CSV_CATALOG << " catalog" << endl )
-    BESCatalogList::TheCatalogList()->del_catalog( CSV_CATALOG ) ;
+    BESDEBUG( "csv", "    removing " << CSV_CATALOG << " catalog" << endl ) ;
+    BESCatalogList::TheCatalogList()->deref_catalog( CSV_CATALOG ) ;
 
-    BESDEBUG( "csv", "Done Cleaning CSV Module" << modname << endl )
+    BESDEBUG( "csv", "Done Cleaning CSV Module" << modname << endl ) ;
 }
 
 extern "C"
