@@ -3,26 +3,26 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
- 
+
 // (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
@@ -31,6 +31,7 @@
 //      jgarcia     Jose Garcia <jgarcia@ucar.edu>
 
 #include <sstream>
+#include <iostream>
 
 using std::ostringstream;
 
@@ -121,8 +122,8 @@ BESDapError::handleException( BESError &e, BESDataHandlerInterface &dhi )
     // DapErrorInfo object to transmit/print the error as a dap2
     // response.
     bool found = false ;
-    string context =
-	BESContextManager::TheManager()->get_context( "errors", found ) ;
+    // I changed 'dap_format' to 'errors' in the following line. jhrg 10/6/08
+    string context = BESContextManager::TheManager()->get_context( "errors", found ) ;
     if( context == "dap2" )
     {
 	ErrorCode ec = unknown_error ;
@@ -142,7 +143,8 @@ BESDapError::handleException( BESError &e, BESDataHandlerInterface &dhi )
 	// handler exception, then convert the error message to include the
 	// error code. If it is or is not a dap exception, we simply return
 	// that the exception was not handled.
-	BESDapError *de = dynamic_cast<BESDapError*>( &e);
+	BESError *e_p = &e ;
+	BESDapError *de = dynamic_cast<BESDapError*>( e_p );
 	if( de )
 	{
 	    ostringstream s;
@@ -157,3 +159,20 @@ BESDapError::handleException( BESError &e, BESDataHandlerInterface &dhi )
     return 0 ;
 }
 
+/** @brief dumps information about this object
+ *
+ * Displays the pointer value of this instance and the stored error code
+ *
+ * @param strm C++ i/o stream to dump the information to
+ */
+void
+BESDapError::dump( ostream &strm ) const
+{
+    strm << BESIndent::LMarg << "BESDapError::dump - ("
+	 << (void *)this << ")" << endl ;
+    BESIndent::Indent() ;
+    strm << BESIndent::LMarg << "error code = " << get_error_code() << endl ;
+    BESError::dump( strm ) ;
+    BESIndent::UnIndent() ;
+}
+
