@@ -3,26 +3,26 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
- 
+
 // (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
@@ -48,19 +48,20 @@ using std::string ;
 
 #include "BESUtil.h"
 
-/** @brief macro used to send debug information to the debut stream
+/** @brief macro used to send debug information to the debug stream
  *
  * The BESDEBUG macro is used by developers to display debug information
  * if the specified debug context is set to true.
  *
  * example:
  *
- * BESDEBUG( "bes", "function entered with values " << val1 << " and " << val2 << endl )
+ * BESDEBUG( "bes", "function entered with values " << val1 << " and "
+ *                  << val2 << endl ) ;
  *
  * @param x the debug context to check
  * @param y information to send to the output stream
  */
-#define BESDEBUG( x, y ) { if( BESDebug::IsSet( x ) ) *(BESDebug::GetStrm()) << "[" << BESDebug::GetPidStr() << "] " << y ; }
+#define BESDEBUG( x, y ) if( BESDebug::IsSet( x ) ) *(BESDebug::GetStrm()) << "[" << BESDebug::GetPidStr() << "] " << y
 
 /** @brief macro used to determine if the specified debug context is set
  *
@@ -73,7 +74,7 @@ using std::string ;
  * {
  *     for( int i = 0; i < _list_size; i++ )
  *     {
- *         BESDEBUG( "bes", " _list[" << i << "] = " << _list[i] << endl )
+ *         BESDEBUG( "bes", " _list[" << i << "] = " << _list[i] << endl ) ;
  *     }
  * }
  *
@@ -87,7 +88,6 @@ private:
     static map<string,bool>	_debug_map ;
     static ostream *		_debug_strm ;
     static bool			_debug_strm_created ;
-    static string		_pid_str ;
     typedef map<string,bool>::const_iterator _debug_citer ;
     typedef map<string,bool>::iterator _debug_iter ;
 public:
@@ -165,20 +165,8 @@ public:
 				    return _debug_strm ;
 				}
 
-    /** @brief return the pid as a string
-     *
-     * @return the pid as a string
-     */
-    static string		GetPidStr()
-				{
-				    if( _pid_str.empty() )
-				    {
-					char mypid[12] ;
-					BESUtil::fastpidconverter( mypid, 10 ) ;
-					_pid_str = mypid ;
-				    }
-				    return _pid_str ;
-				}
+    static string		GetPidStr() ;
+
     /** @brief set the debug output stream to the specified stream
      *
      * Static method that sets the debug output stream to the specified ostream.
@@ -192,7 +180,7 @@ public:
      * set the static _debug_strm_created flag to the passed created flag
      *
      * @param strm set the current debug stream to strm
-     * @param created wether the passed debug stream was created
+     * @param created whether the passed debug stream was created
      */
     static void			SetStrm( ostream *strm, bool created )
     				{
@@ -228,11 +216,14 @@ int
 main( int argc, char **argv )
 {
     int some_number = 1 ;
-    BESDEBUG( "something", "Shouldn't be seeing this part 1: " << some_number++ << endl )
+    BESDEBUG( "something", "Shouldn't be seeing this part 1: "
+                           << some_number++ << endl ) ;
     BESDebug::Set( "something", false ) ;
-    BESDEBUG( "something", "Shouldn't be seeing this part 2: " << some_number++ << endl )
+    BESDEBUG( "something", "Shouldn't be seeing this part 2: "
+                           << some_number++ << endl ) ;
     BESDebug::Set( "something", true ) ;
-    BESDEBUG( "something", "Should be seeing this: " << some_number++ << endl )
+    BESDEBUG( "something", "Should be seeing this: "
+                           << some_number++ << endl ) ;
 
     return 0 ;
 }
