@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -83,17 +83,17 @@ BESMemoryManager::check_memory_pool()
 { 
     if( _storage_used )
     {
-	BESDEBUG( "bes", "BES: global pool is used, trying to get it back..." << endl )
+	BESDEBUG( "bes", "BES: global pool is used, trying to get it back..." << endl ) ;
 	//Try to regain the memory...
 	if( _memory->reclaim_memory() )
 	{
 	    _storage_used = false ;
-	    BESDEBUG( "bes", "OK" << endl )
+	    BESDEBUG( "bes", "OK" << endl ) ;
 	    return true ;
 	}
 	else
 	{
-	    BESDEBUG( "bes", "FAILED" << endl )
+	    BESDEBUG( "bes", "FAILED" << endl ) ;
 	    return false ;
 	}
     }
@@ -109,7 +109,7 @@ BESMemoryManager::release_global_pool() throw (bad_alloc)
     // Without this pool of memory for emergencies we will get really
     // unexpected behavior from the program.
     BESDEBUG( "bes", "BES Warning: low in memory, "
-	      << "releasing global memory pool!" << endl )
+	      << "releasing global memory pool!" << endl ) ;
     *(BESLog::TheLog()) << "BES Warning: low in memory, "
                         << "releasing global memory pool!"
 		        << endl;
