@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -40,6 +40,7 @@ using std::endl ;
 #include "BESPluginFactory.h"
 #include "BESAbstractModule.h"
 #include "TheBESKeys.h"
+#include "BESUtil.h"
 
 /** @brief Default constructor
  *
@@ -104,73 +105,97 @@ BESModuleApp::loadModules()
     int retVal = 0 ;
 
     bool found = false ;
-    string mods = TheBESKeys::TheKeys()->get_key( "BES.modules", found ) ;
-    if( mods != "" )
+    vector<string> vals ;
+    TheBESKeys::TheKeys()->get_values( "BES.modules", vals, found ) ;
+    vector<string>::iterator l = vals.begin() ;
+    vector<string>::iterator le = vals.end() ;
+
+    // FIXME: This is a kludge. But we want to be sure that the dap
+    // modules get loaded first.
+    vector<string> ordered_list ;
+    for( ; l != le; l++ )
     {
-	std::string::size_type start = 0 ;
-	std::string::size_type comma = 0 ;
-	bool done = false ;
-	while( !done )
+	string mods = (*l) ;
+	if( mods != "" )
 	{
-	    string mod ;
-	    comma = mods.find( ',', start ) ;
-	    if( comma == string::npos )
+	    if( mods.find( "dap", 0 ) != string::npos )
 	    {
-		mod = mods.substr( start, mods.length() - start ) ;
-		done = true ;
+		ordered_list.insert( ordered_list.begin(), mods ) ;
 	    }
 	    else
 	    {
-		mod = mods.substr( start, comma - start ) ;
+		ordered_list.push_back( mods ) ;
 	    }
-	    string key = "BES.module." + mod ;
-	    string so = TheBESKeys::TheKeys()->get_key( key, found ) ;
-	    if( so == "" )
-	    {
-		cerr << "couldn't find the module for " << mod << endl ;
-		return 1 ;
-	    }
-	    bes_module new_mod ;
-	    new_mod._module_name = mod ;
-	    new_mod._module_library = so ;
-	    _module_list.push_back( new_mod ) ;
-
-	    start = comma + 1 ;
 	}
+    }
 
-	list< bes_module >::iterator i = _module_list.begin() ;
-	list< bes_module >::iterator e = _module_list.end() ;
+    l = ordered_list.begin() ;
+    le = ordered_list.end() ;
+    for( ; l != le; l++ )
+    {
+	string mods = (*l) ;
+	list<string> mod_list ;
+	BESUtil::explode( ',', mods, mod_list ) ;
+
+	list<string>::iterator i = mod_list.begin() ;
+	list<string>::iterator e = mod_list.end() ;
 	for( ; i != e; i++ )
 	{
-	    bes_module curr_mod = *i ;
-	    _moduleFactory.add_mapping( curr_mod._module_name, curr_mod._module_library ) ;
-	}
-
-	for( i = _module_list.begin(); i != e; i++ )
-	{
-	    bes_module curr_mod = *i ;
+	    string key = "BES.module." + (*i) ;
+	    string so ;
 	    try
 	    {
-		string modname = curr_mod._module_name ;
-		BESAbstractModule *o = _moduleFactory.get( modname ) ;
-		o->initialize( modname ) ;
-		delete o ;
+		TheBESKeys::TheKeys()->get_value( key, so, found ) ;
 	    }
 	    catch( BESError &e )
 	    {
-		cerr << "Caught plugin exception during initialization of "
-		     << curr_mod._module_name << " module:" << endl << "    "
-		     << e.get_message() << endl ;
-		retVal = 1 ;
-		break ;
+		cerr << e.get_message() << endl ;
+		return 1 ;
 	    }
-	    catch( ... )
+	    if( so == "" )
 	    {
-		cerr << "Caught unknown exception during initialization of "
-		     << curr_mod._module_name << " module" << endl ;
-		retVal = 1 ;
-		break ;
+		cerr << "couldn't find the module for " << (*i) << endl ;
+		return 1 ;
 	    }
+	    bes_module new_mod ;
+	    new_mod._module_name = (*i) ;
+	    new_mod._module_library = so ;
+	    _module_list.push_back( new_mod ) ;
+	}
+    }
+
+    list< bes_module >::iterator mi = _module_list.begin() ;
+    list< bes_module >::iterator me = _module_list.end() ;
+    for( ; mi != me; mi++ )
+    {
+	bes_module curr_mod = *mi ;
+	_moduleFactory.add_mapping( curr_mod._module_name, curr_mod._module_library ) ;
+    }
+
+    for( mi = _module_list.begin(); mi != me; mi++ )
+    {
+	bes_module curr_mod = *mi ;
+	try
+	{
+	    string modname = curr_mod._module_name ;
+	    BESAbstractModule *o = _moduleFactory.get( modname ) ;
+	    o->initialize( modname ) ;
+	    delete o ;
+	}
+	catch( BESError &e )
+	{
+	    cerr << "Caught plugin exception during initialization of "
+		 << curr_mod._module_name << " module:" << endl << "    "
+		 << e.get_message() << endl ;
+	    retVal = 1 ;
+	    break ;
+	}
+	catch( ... )
+	{
+	    cerr << "Caught unknown exception during initialization of "
+		 << curr_mod._module_name << " module" << endl ;
+	    retVal = 1 ;
+	    break ;
 	}
     }
 
