@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -62,7 +62,8 @@ BESUncompressManager::BESUncompressManager()
 
     bool found = false ;
     string key = "BES.Uncompress.Retry" ;
-    string val = TheBESKeys::TheKeys()->get_key( key, found ) ;
+    string val ;
+    TheBESKeys::TheKeys()->get_value( key, val, found ) ;
     if( !found || val.empty() )
     {
 	_retry = 2000 ;
@@ -74,7 +75,8 @@ BESUncompressManager::BESUncompressManager()
     }
 
     key = "BES.Uncompress.NumTries" ;
-    val = TheBESKeys::TheKeys()->get_key( key, found ) ;
+    val = "" ;
+    TheBESKeys::TheKeys()->get_value( key, val, found ) ;
     if( !found || val.empty() )
     {
 	_num_tries = 10 ;
@@ -188,13 +190,20 @@ BESUncompressManager::get_method_names()
  * (gzipped file) then we find the uncompress function with the name gz. The
  * cache is then unlocked and the target returned.
  *
- * If the file extension can not be found in the list then the source file
+ * If the file extension cannot be found in the list then the source file
  * is returned as the target file. If, for example, a compressed file with
  * the extension .bozo is passed as the source file, and there is no
  * uncompression function with the name bozo, then the src file with the
  * extension .bozo is returned as is.
  *
+ * If there is a problem uncompressing the file, the uncompress code is
+ * responsible for closing the source file, the target file, AND
+ * REMOVING THE TARGET FILE. If the target file is left in place after
+ * an error, then the cache might use that file in the future for a
+ * request.
+ *
  * @param src file to be uncompressed
+ * @param target target file to uncompress into
  * @param cache BESCache object to uncompress the src file in
  * @return full path to the uncompressed file
  * @throws BESInternalError if there is a problem uncompressing
@@ -204,7 +213,7 @@ bool
 BESUncompressManager::uncompress( const string &src, string &target,
 				  BESCache &cache )
 {
-    BESDEBUG( "bes", "BESUncompressManager::uncompress - src = " << src << endl )
+    BESDEBUG( "bes", "BESUncompressManager::uncompress - src = " << src << endl ) ;
     string::size_type dot = src.rfind( "." ) ;
     if( dot != string::npos )
     {
@@ -234,10 +243,10 @@ BESUncompressManager::uncompress( const string &src, string &target,
 		    // before calling uncompress on the file, see if the file
 		    // has already been cached. If it has, then simply return
 		    // the target, no need to cache.
-		    BESDEBUG( "bes", "BESUncompressManager::uncompress - is cached? " << src << endl )
+		    BESDEBUG( "bes", "BESUncompressManager::uncompress - is cached? " << src << endl ) ;
 		    if( cache.is_cached( src, target ) )
 		    {
-			BESDEBUG( "bes", "BESUncompressManager::uncompress - "  << "is cached " << target << endl )
+			BESDEBUG( "bes", "BESUncompressManager::uncompress - "  << "is cached " << target << endl ) ;
 			cache.unlock() ;
 			return true ;
 		    }
@@ -245,13 +254,14 @@ BESUncompressManager::uncompress( const string &src, string &target,
 		    // the file is not cached, so we need to uncompress the
 		    // file.  First determine if there is enough space in
 		    // the cache to uncompress the file
-		    BESDEBUG( "bes", "BESUncompressManager::uncompress - " << "purging cache" << endl )
+		    BESDEBUG( "bes", "BESUncompressManager::uncompress - " << "purging cache" << endl ) ;
 		    cache.purge() ;
 
 		    // Now that we have some room ... uncompress the file
-		    BESDEBUG( "bes", "BESUncompressManager::uncompress - " << "uncompress to " << target \
-			      << " using " << ext << " uncompression" \
-			      << endl )
+		    BESDEBUG( "bes", "BESUncompressManager::uncompress - "
+				     << "uncompress to " << target
+				     << " using " << ext << " uncompression"
+				     << endl ) ;
 
 		    // we are now done in the cahce, unlock it
 		    cache.unlock() ;
@@ -285,12 +295,12 @@ BESUncompressManager::uncompress( const string &src, string &target,
 	}
 	else
 	{
-	    BESDEBUG( "bes", "BESUncompressManager::uncompress - not compressed " << endl )
+	    BESDEBUG( "bes", "BESUncompressManager::uncompress - not compressed " << endl ) ;
 	}
     }
     else
     {
-	BESDEBUG( "bes", "BESUncompressmanager::uncompress - not file extension" << endl )
+	BESDEBUG( "bes", "BESUncompressmanager::uncompress - not file extension" << endl ) ;
 #if 0
 	// This could just mean that there is a README file here, so just
 	// return the src file name and let the system run its course.
