@@ -3,26 +3,26 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
- 
+
 // (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
@@ -39,6 +39,7 @@
 #include <unistd.h>
 #endif
 
+#include <cstdio>
 #include <cerrno>
 #include <cstring>
 #include <cstdlib>
@@ -52,6 +53,7 @@ using std::endl ;
 #include "BESUtil.h"
 #include "BESForbiddenError.h"
 #include "BESNotFoundError.h"
+#include "BESInternalError.h"
 
 #define CRLF "\r\n"
 
@@ -128,7 +130,7 @@ BESUtil::set_mime_html( ostream &strm )
 //                                                   ;  hours+min. (HHMM)
 
 static const char *days[]={"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
-static const char *months[]={"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", 
+static const char *months[]={"Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul",
 			"Aug", "Sep", "Oct", "Nov", "Dec"};
 
 /** Given a constant pointer to a <tt>time_t</tt>, return a RFC
@@ -154,8 +156,8 @@ BESUtil::rfc822_date(const time_t t)
     return string(d);
 }
 
-string 
-BESUtil::unhexstring( string s ) 
+string
+BESUtil::unhexstring( string s )
 {
     int val;
     istringstream ss( s ) ;
@@ -166,13 +168,15 @@ BESUtil::unhexstring( string s )
     return string(tmp_str);
 }
 
-string 
+// I modified this to mirror the version in libdap. The change allows several
+// escape sequences to by listed in 'except'. jhrg 2/18/09
+string
 BESUtil::www2id(const string &in, const string &escape, const string &except)
 {
     string::size_type i = 0;
     string res = in;
     while ((i = res.find_first_of(escape, i)) != string::npos) {
-	if (res.substr(i, 3) == except) {
+	if (except.find(res.substr(i, 3)) != string::npos) {
 	    i += 3;
 	    continue;
 	}
@@ -409,3 +413,216 @@ BESUtil::fastpidconverter(
       return buf;
 }
 
+void
+BESUtil::removeLeadingAndTrailingBlanks( string &key )
+{
+    if( !key.empty() )
+    {
+	string::size_type first = key.find_first_not_of( " \t\n\r" ) ;
+	string::size_type last = key.find_last_not_of( " \t\n\r" ) ;
+	if( first == string::npos ) key = "" ;
+	else
+	{
+	    string::size_type num = last - first + 1 ;
+	    string new_key = key.substr( first, num ) ;
+	    key = new_key ;
+	}
+    }
+}
+
+string
+BESUtil::entity( char c )
+{
+    switch( c )
+    {
+	case '>': return "&gt;";
+	case '<': return "&lt;";
+	case '&': return "&amp;";
+	case '\'': return "&apos;";
+	case '\"': return "&quot;";
+    }
+}
+
+/** Replace characters that are not allowed in XML
+
+    @param in The string in which to replace characters.
+    @param not_allowed The set of characters that are not allowed in XML.
+    default: ><&'(single quote)"(double quote)
+    @return The modified identifier. */
+string
+BESUtil::id2xml( string in, const string &not_allowed )
+{
+    string::size_type i = 0 ;
+
+    while( ( i = in.find_first_of( not_allowed, i ) ) != string::npos )
+    {
+        in.replace( i, 1, entity( in[i] ) ) ;
+        i++ ;
+    }
+
+    return in ;
+}
+
+/** Given a string that contains XML escape sequences (i.e., entities),
+    translate those back into ASCII characters. Return the modified string.
+
+    @param in The string to modify.
+    @return The modified string. */
+string
+BESUtil::xml2id(string in)
+{
+    string::size_type i = 0;
+
+    while ((i = in.find("&gt;", i)) != string::npos)
+        in.replace(i, 4, ">");
+
+    i = 0;
+    while ((i = in.find("&lt;", i)) != string::npos)
+        in.replace(i, 4, "<");
+
+    i = 0;
+    while ((i = in.find("&amp;", i)) != string::npos)
+        in.replace(i, 5, "&");
+
+    i = 0;
+    while ((i = in.find("&apos;", i)) != string::npos)
+        in.replace(i, 6, "'");
+
+    i = 0;
+    while ((i = in.find("&quot;", i)) != string::npos)
+        in.replace(i, 6, "\"");
+
+    return in;
+}
+
+/** Given a string of values separated by a delimiter, break out the values
+ * and store in the list.
+ *
+ * Quoted values must be escaped.
+ *
+ * If values contain the delimiter then the value must be wrapped in quotes.
+ *
+ * @param delim delimiter separating the values
+ * @param str the original string
+ * @param values list of the delimited values returned to caller
+ * @throws BESInternalError if missing ending quote or delimiter does not
+ * follow end quote
+ */
+void
+BESUtil::explode( char delim, const string &str, list<string> &values )
+{
+    std::string::size_type start = 0 ;
+    std::string::size_type qstart = 0 ;
+    std::string::size_type adelim = 0 ;
+    std::string::size_type aquote = 0 ;
+    bool done = false ;
+    while( !done )
+    {
+	string aval ;
+	if( str[start] == '"' )
+	{
+	    bool endquote = false ;
+	    qstart = start+1 ;
+	    while( !endquote )
+	    {
+		aquote = str.find( '"', qstart ) ;
+		if( aquote == string::npos )
+		{
+		    string currval = str.substr( start, str.length() - start ) ;
+		    string err = "BESUtil::explode - No end quote after value "
+				 + currval ;
+		    throw BESInternalError( err, __FILE__, __LINE__ ) ;
+		}
+		// could be an escaped escape character and an escaped
+		// quote, or an escaped escape character and a quote
+		if( str[aquote-1] == '\\' )
+		{
+		    if( str[aquote-2] == '\\' )
+		    {
+			endquote = true ;
+			qstart = aquote + 1 ;
+		    }
+		    else
+		    {
+			qstart = aquote+1 ;
+		    }
+		}
+		else
+		{
+		    endquote = true ;
+		    qstart = aquote + 1 ;
+		}
+	    }
+	    if( str[qstart] != delim && qstart != str.length() )
+	    {
+		string currval = str.substr( start, qstart - start ) ;
+		string err = "BESUtil::explode - No delim after end quote "
+			     + currval ;
+		throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	    }
+	    if( qstart == str.length() )
+	    {
+		adelim = string::npos ;
+	    }
+	    else
+	    {
+		adelim = qstart ;
+	    }
+	}
+	else
+	{
+	    adelim = str.find( delim, start ) ;
+	}
+	if( adelim == string::npos )
+	{
+	    aval = str.substr( start, str.length() - start ) ;
+	    done = true ;
+	}
+	else
+	{
+	    aval = str.substr( start, adelim - start ) ;
+	}
+	values.push_back( aval ) ;
+	start = adelim + 1 ;
+	if( start == str.length() )
+	{
+	    done = true ;
+	}
+    }
+}
+
+/** Given a list of string values create a single string of values
+ * delimited by delim
+ *
+ * If the delimiter exists in a value in the list then that value must
+ * be enclosed in quotes
+ *
+ * @param values list of string values to implode
+ * @param delim the delimiter to use in creating the resulting string
+ * @return the delim delimited string of values
+ */
+string
+BESUtil::implode( const list<string> &values, char delim )
+{
+    string result ;
+    list<string>::const_iterator i = values.begin() ;
+    list<string>::const_iterator e = values.end() ;
+    bool first = true ;
+    string::size_type d; // = string::npos ;
+    for( ; i != e; i++ )
+    {
+	if( !first ) result += delim ;
+	d = (*i).find( delim ) ;
+	if( d != string::npos && (*i)[0] != '"' )
+	{
+	    string err = (string)"BESUtil::implode - delimiter exists in value "
+			 + (*i) ;
+	    throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	}
+	//d = string::npos ;
+	result += (*i) ;
+	first = false ;
+    }
+    return result ;
+}
+
