@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -45,6 +45,7 @@ using std::ostringstream ;
 #include "UnixSocket.h"
 #include "PPTProtocol.h"
 #include "BESInternalError.h"
+#include "BESSyntaxUserError.h"
 #include "TheBESKeys.h"
 
 #include "config.h"
@@ -78,27 +79,27 @@ void
 PPTClient::get_secure_files()
 {
     bool found = false ;
-    _cfile = TheBESKeys::TheKeys()->get_key( "BES.ClientCertFile", found ) ;
+    TheBESKeys::TheKeys()->get_value( "BES.ClientCertFile", _cfile, found ) ;
     if( !found || _cfile.empty() )
     {
 	string err = "Unable to determine client certificate file." ;
-	throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	throw BESSyntaxUserError( err, __FILE__, __LINE__ ) ;
     }
 
     found = false ;
-    _cafile = TheBESKeys::TheKeys()->get_key( "BES.ClientCertAuthFile", found );
+    TheBESKeys::TheKeys()->get_value( "BES.ClientCertAuthFile", _cafile, found);
     if( !found || _cafile.empty() )
     {
 	string err = "Unable to determine client certificate authority file." ;
-	throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	throw BESSyntaxUserError( err, __FILE__, __LINE__ ) ;
     }
 
     found = false ;
-    _kfile = TheBESKeys::TheKeys()->get_key( "BES.ClientKeyFile", found ) ;
+    TheBESKeys::TheKeys()->get_value( "BES.ClientKeyFile", _kfile, found ) ;
     if( !found || _kfile.empty() )
     {
 	string err = "Unable to determine client key file." ;
-	throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	throw BESSyntaxUserError( err, __FILE__, __LINE__ ) ;
     }
 }
 
@@ -129,8 +130,11 @@ PPTClient::initConnection()
 	throw BESInternalError( msg, __FILE__, __LINE__ ) ;
     }
 
-    char *inBuff = new char[PPT_PROTOCOL_BUFFER_SIZE+1] ;
-    int bytesRead = readBufferNonBlocking( inBuff ) ;
+    // we're just getting tokens, not a big buffer, so don't need that big
+    // of a buffer. pcw 05/31/08
+    unsigned int ppt_buffer_size = 64 ;
+    char *inBuff = new char[ppt_buffer_size+1] ;
+    int bytesRead = readBufferNonBlocking( inBuff, ppt_buffer_size ) ;
     if( bytesRead < 1 )
     {
 	delete [] inBuff ;
@@ -138,8 +142,8 @@ PPTClient::initConnection()
 	throw BESInternalError( err, __FILE__, __LINE__) ;
     }
 
-    if( bytesRead > PPT_PROTOCOL_BUFFER_SIZE )
-	bytesRead = PPT_PROTOCOL_BUFFER_SIZE ;
+    if( bytesRead > ppt_buffer_size )
+	bytesRead = ppt_buffer_size ;
     inBuff[bytesRead] = '\0' ;
     string status( inBuff, 0, bytesRead ) ;
     delete [] inBuff ;
@@ -172,9 +176,12 @@ PPTClient::authenticateWithServer()
     // send request for the authentication port
     send( PPTProtocol::PPTCLIENT_REQUEST_AUTHPORT ) ;
 
-    // receive response with port, terminated with TERMINATE token
-    char *inBuff = new char[PPT_PROTOCOL_BUFFER_SIZE+1] ;
-    int bytesRead = readBufferNonBlocking( inBuff ) ;
+    // receive response with port, terminated with TERMINATE token. We are
+    // exchanging a port number and a terminating token. The buffer doesn't
+    // need to be too big. pcw 05/31/08
+    unsigned int ppt_buffer_size = 64 ;
+    char *inBuff = new char[ppt_buffer_size+1] ;
+    int bytesRead = readBufferNonBlocking( inBuff, ppt_buffer_size ) ;
     if( bytesRead < 1 )
     {
 	delete [] inBuff ;
@@ -182,9 +189,9 @@ PPTClient::authenticateWithServer()
 	throw BESInternalError( err, __FILE__, __LINE__ ) ;
     }
 
-    if( bytesRead > PPT_PROTOCOL_BUFFER_SIZE )
+    if( bytesRead > ppt_buffer_size )
     {
-	bytesRead = PPT_PROTOCOL_BUFFER_SIZE ;
+	bytesRead = ppt_buffer_size ;
     }
     inBuff[bytesRead] = '\0' ;
     ostringstream portResponse( inBuff ) ;
@@ -205,9 +212,7 @@ PPTClient::authenticateWithServer()
     // If it authenticates, good, if not then an exception is thrown. We
     // don't need to do anything else here.
 #else
-    string err = "Server has requested authentication "
-                 + "but OpenSSL is not built into this client" ;
-    throw BESInternalError( err, __FILE__, __LINE__ ) ;
+    throw BESInternalError( "Server has requested authentication, but OpenSSL is not built into this client", __FILE__, __LINE__ ) ;
 #endif
 }
 
