@@ -3,7 +3,7 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
@@ -37,10 +37,6 @@
 
 using std::string ;
 
-#define PPT_PROTOCOL_BUFFER_SIZE 65550
-#define PPT_PROTOCOL_CHUNK_SIZE 65535
-#define CRLF "\r\n"
-
 class PPTProtocol
 {
 public:
