@@ -3,26 +3,26 @@
 // This file is part of bes, A C++ back-end server implementation framework
 // for the OPeNDAP Data Access Protocol.
 
-// Copyright (c) 2004,2005 University Corporation for Atmospheric Research
+// Copyright (c) 2004-2009 University Corporation for Atmospheric Research
 // Author: Patrick West <pwest@ucar.edu> and Jose Garcia <jgarcia@ucar.edu>
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact University Corporation for Atmospheric Research at
 // 3080 Center Green Drive, Boulder, CO 80301
- 
+
 // (c) COPYRIGHT University Corporation for Atmospheric Research 2004-2005
 // Please read the full copyright statement in the file COPYRIGHT_UCAR.
 //
@@ -30,14 +30,18 @@
 //      pwest       Patrick West <pwest@ucar.edu>
 //      jgarcia     Jose Garcia <jgarcia@ucar.edu>
 
+#include <config.h>
+
 #include <string>
 #include <sstream>
+#include <cstdlib>
 
 using std::string ;
 using std::ostringstream ;
 
 #include "PPTServer.h"
 #include "BESInternalError.h"
+#include "BESSyntaxUserError.h"
 #include "PPTProtocol.h"
 #include "SocketListener.h"
 #include "ServerHandler.h"
@@ -93,45 +97,47 @@ void
 PPTServer::get_secure_files()
 {
     bool found = false ;
-    _cfile = TheBESKeys::TheKeys()->get_key( "BES.ServerCertFile", found ) ;
+    TheBESKeys::TheKeys()->get_value( "BES.ServerCertFile", _cfile, found ) ;
     if( !found || _cfile.empty() )
     {
 	string err = "Unable to determine server certificate file." ;
-	throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	throw BESSyntaxUserError( err, __FILE__, __LINE__ ) ;
     }
 
     found = false ;
-    _cafile = TheBESKeys::TheKeys()->get_key( "BES.ServerCertAuthFile", found );
+    TheBESKeys::TheKeys()->get_value( "BES.ServerCertAuthFile", _cafile, found);
     if( !found || _cafile.empty() )
     {
 	string err = "Unable to determine server certificate authority file." ;
-	throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	throw BESSyntaxUserError( err, __FILE__, __LINE__ ) ;
     }
 
-    _kfile = TheBESKeys::TheKeys()->get_key( "BES.ServerKeyFile", found ) ;
+    found = false ;
+    TheBESKeys::TheKeys()->get_value( "BES.ServerKeyFile", _kfile, found ) ;
     if( !found || _kfile.empty() )
     {
 	string err = "Unable to determine server key file." ;
-	throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	throw BESSyntaxUserError( err, __FILE__, __LINE__ ) ;
     }
 
-    string portstr =
-	TheBESKeys::TheKeys()->get_key( "BES.ServerSecurePort", found ) ;
+    found = false ;
+    string portstr ;
+    TheBESKeys::TheKeys()->get_value( "BES.ServerSecurePort", portstr, found ) ;
     if( !found || portstr.empty() )
     {
 	string err = "Unable to determine secure connection port." ;
-	throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	throw BESSyntaxUserError( err, __FILE__, __LINE__ ) ;
     }
     _securePort = atoi( portstr.c_str() ) ;
     if( !_securePort )
     {
 	string err = (string)"Unable to determine secure connection port "
 	             + "from string " + portstr ;
-	throw BESInternalError( err, __FILE__, __LINE__ ) ;
+	throw BESSyntaxUserError( err, __FILE__, __LINE__ ) ;
     }
 }
 
-/** Using the info passed into the SocketLister, wait for an inbound 
+/** Using the info passed into the SocketLister, wait for an inbound
     request (see SocketListener::accept()). When one is found, do the
     welcome message stuff (welcomeClient()) and then pass \c this to
     the handler's \c handle method. Note that \c this is a pointer to
@@ -144,11 +150,18 @@ PPTServer::initConnection()
 	_mySock = _listener->accept() ;
 	if( _mySock )
 	{
-	    // welcome the client
-	    if( welcomeClient( ) != -1 )
+	    if( _mySock->allowConnection() == true )
 	    {
-		// now hand it off to the handler
-		_handler->handle( this ) ;
+		// welcome the client
+		if( welcomeClient( ) != -1 )
+		{
+		    // now hand it off to the handler
+		    _handler->handle( this ) ;
+		}
+	    }
+	    else
+	    {
+               _mySock->close();
 	    }
 	}
     }
@@ -163,12 +176,15 @@ PPTServer::closeConnection()
 int
 PPTServer::welcomeClient()
 {
-    char *inBuff = new char[PPT_PROTOCOL_BUFFER_SIZE] ;
-    /* Doing a non blocking read in case the connection is being initiated
-     * by a non-bes client. Don't want this to block. pcw - 3/5/07
-    int bytesRead = _mySock->receive( inBuff, PPT_PROTOCOL_BUFFER_SIZE ) ;
-     */
-    int bytesRead = readBufferNonBlocking( inBuff ) ;
+    // Doing a non blocking read in case the connection is being initiated
+    // by a non-bes client. Don't want this to block. pcw - 3/5/07
+    // int bytesRead = _mySock->receive( inBuff, ppt_buffer_size ) ;
+    //
+    // We are receiving handshaking tokens, so the buffer doesn't need to be
+    // all that big. pcw - 05/31/08
+    unsigned int ppt_buffer_size = 64 ;
+    char *inBuff = new char[ppt_buffer_size+1] ;
+    int bytesRead = readBufferNonBlocking( inBuff, ppt_buffer_size ) ;
 
     // if the read of the initial connection fails or blocks, then return
     if( bytesRead == -1 )
@@ -183,13 +199,13 @@ PPTServer::welcomeClient()
 
     if( status != PPTProtocol::PPTCLIENT_TESTING_CONNECTION )
     {
-	/* If can not negotiate with the client then we don't want to exit
+	/* If cannot negotiate with the client then we don't want to exit
 	 * by throwing an exception, we want to return and let the caller
 	 * clean up the connection
 	 */
-	string err( "PPT Can not negotiate, " ) ;
+	string err( "PPT cannot negotiate, " ) ;
 	err += " client started the connection with " + status ;
-	BESDEBUG( "ppt", err << endl )
+	BESDEBUG( "ppt", err << endl ) ;
 	//throw BESInternalError( err, __FILE__, __LINE__ ) ;
 	send( err ) ;
 	_mySock->close() ;
@@ -212,13 +228,17 @@ void
 PPTServer::authenticateClient()
 {
 #ifdef HAVE_OPENSSL
-    BESDEBUG( "ppt", "requiring secure connection: port = " << _securePort << endl )
+    BESDEBUG( "ppt", "requiring secure connection: port = "
+		     << _securePort << endl ) ;
     // let the client know that it needs to authenticate
     send( PPTProtocol::PPTSERVER_AUTHENTICATE ) ;
 
     // wait for the client request for the secure port
-    char *inBuff = new char[PPT_PROTOCOL_BUFFER_SIZE] ;
-    int bytesRead = _mySock->receive( inBuff, PPT_PROTOCOL_BUFFER_SIZE ) ;
+    // We are waiting for a ppt tocken requesting the secure port number.
+    // The buffer doesn't need to be all that big. pcw - 05/31/08
+    unsigned int ppt_buffer_size = 64 ;
+    char *inBuff = new char[ppt_buffer_size] ;
+    int bytesRead = _mySock->receive( inBuff, ppt_buffer_size ) ;
     string portRequest( inBuff, bytesRead ) ;
     delete [] inBuff ;
     if( portRequest != PPTProtocol::PPTCLIENT_REQUEST_AUTHPORT )
@@ -241,7 +261,7 @@ PPTServer::authenticateClient()
     // if it authenticates, good, if not, an exception is thrown, no need to
     // do anything else here.
 #else
-    string err = "Authentication requested for this server "
+    string err = (string)"Authentication requested for this server "
                  + "but OpenSSL is not built into the server" ;
     throw BESInternalError( err, __FILE__, __LINE__ ) ;
 #endif
